@@ -32,30 +32,16 @@ class Dict(dict):
         subdicts into Dicts as well.
 
         """
-        if (args and isinstance(args[0], dict)):
+        if args and isinstance(args[0], dict):
             for key, val in args[0].items():
-                self._set_both(key, val)
+                self[key] = val
 
     def __setattr__(self, name, value):
         """
         setattr is called when the syntax a.b = 2 is used to set a value.
 
         """
-        self._set_both(name, value)
-
-    def _set_both(self, name, value):
-        """
-        This method does the 'heavy' lifting here. If value is an instance
-        of dict, it will be turned into a Dict (Yay!). If name is a string,
-        it can be set as a property. If name is not in the Dict already,
-        we put it in :-)
-
-        """
-        if isinstance(value, dict):
-            value = self.__class__(value)
-        if isinstance(name, str):
-            super(Dict, self).__setattr__(name, value)
-            super(Dict, self).__setitem__(name, value)
+        self.__setitem__(name, value)
 
     def __setitem__(self, name, value):
         """
@@ -63,17 +49,12 @@ class Dict(dict):
         E.g. some_instance_of_Dict['b'] = val. If 'val
 
         """
-        self._set_both(name, value)
+        if isinstance(value, dict):
+            value = self.__class__(value)
+        super(Dict, self).__setitem__(name, value)
 
-    def __getattr__(self, name):
-        """
-        This is called when __getattribute__ can't find an attribute.
-        So this only handles the cases of missing attributes. This
-        is the defaultdict-like part.
-
-        """
-        self._set_both(name, {})
-        return super(Dict, self).__getattribute__(name)
+    def __getattr__(self, item):
+        return self.__getitem__(item)
 
     def __getitem__(self, name):
         """
@@ -86,7 +67,7 @@ class Dict(dict):
         if name in self:
             return super(Dict, self).__getitem__(name)
         else:
-            self._set_both(name, {})
+            self.__setitem__(name, {})
             return super(Dict, self).__getitem__(name)
 
     def __delattr__(self, name):
@@ -109,7 +90,6 @@ class Dict(dict):
 
         """
         super(Dict, self).__delitem__(name)
-        super(Dict, self).__delattr__(name)
 
     def _prune(self):
         """
@@ -125,7 +105,7 @@ class Dict(dict):
                     self._delete(key)
             elif isinstance(val, list):
                 new_list = self._prune_list(val)
-                self._set_both(key, new_list)
+                self[key] = new_list
 
     @classmethod
     def _prune_list(cls, some_list):
